AsyncNotifierObserver class abstract

An interface for observing the behavior of AsyncNotifier instances.

Constructors

AsyncNotifierObserver()
An interface for observing the behavior of AsyncNotifier instances.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(AsyncNotifier it, AsyncSnapshot prev, AsyncSnapshot next) → void
Called whenever a change occurs in any AsyncNotifier.
onCreate(AsyncNotifier it) → void
Called whenever an AsyncNotifier is instantiated.
onData(AsyncNotifier it, Object? data) → void
Called whenever new data is available in any AsyncNotifier.
onDispose(AsyncNotifier it) → void
Called whenever a AsyncNotifier is disposed.
onDone(AsyncNotifier it) → void
Called whenever a AsyncNotifier is done with its async operation.
onError(AsyncNotifier it, Object error, StackTrace stackTrace) → void
Called whenever an error is thrown in any AsyncNotifier. The stackTrace argument may be StackTrace.empty if an error was received without a stack trace.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited